@@ -19,8 +19,9 @@ Usage::
     ```
 """
 from datetime import datetime
-from typing import Iterator, Union
+from typing import Generic, Iterator, TypeVar, Union
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import AggregationPeriodType, OrderByType
@@ -29,9 +30,19 @@ from .type_defs import ListProfileTimesResponseTypeDef, PaginatorConfigTypeDef
 __all__ = ("ListProfileTimesPaginator",)
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class ListProfileTimesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
     """
 
@@ -44,8 +55,8 @@ class ListProfileTimesPaginator(Boto3Paginator):
         startTime: Union[datetime, str],
         orderBy: OrderByType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListProfileTimesResponseTypeDef]:
+    ) -> _PageIterator[ListProfileTimesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
         """
